@@ -44,7 +44,7 @@ void seed_rand()
   timeval temp_time_struct;
   gettimeofday(&temp_time_struct,NULL);
   srand(temp_time_struct.tv_usec);
-};
+}
 
 void generate_rand_vectors(double scale, uint64_t runs, std::vector<double>& xvalues, std::vector<double>& yvalues, std::vector<double>&zvalues)
 {
@@ -217,11 +217,11 @@ void setupTree(tf::Transformer& mTR, const std::string& mode, const ros::Time &
           else
             ts.stamp_ = ros::Time();
 
-          ts.frame_id_ = frame_prefix + frames[i-1];
+          ts.child_frame_id_ = frame_prefix + frames[i];
           if (i > 1)
-            ts.child_frame_id_ = frame_prefix + frames[i];
+            ts.frame_id_ = frame_prefix + frames[i-1];
           else
-            ts.child_frame_id_ = frames[i]; // connect first frame
+            ts.frame_id_ = frames[i-1]; // connect first frame
           
           EXPECT_TRUE(mTR.setTransform(ts, "authority"));
           if (interpolation_space > ros::Duration())
@@ -1816,7 +1816,7 @@ TEST(tf, NoExtrapolationExceptionFromParent)
 
 
 
-};
+}
 
 
 
@@ -1899,7 +1899,7 @@ TEST(tf, ExtrapolationFromOneValue)
   
   EXPECT_FALSE(excepted);
 
-};
+}
 
 
 
